[![PyPI](https://img.shields.io/pypi/v/autotorch.svg)](https://pypi.python.org/pypi/autotorch)
[![PyPI Pre-release](https://img.shields.io/badge/pypi--prerelease-v0.0.2-ff69b4.svg)](https://pypi.org/project/autotorch/#history)
[![Downloads](http://pepy.tech/badge/autotorch)](http://pepy.tech/project/autotorch)
[![Upload PyPI](https://github.com/StacyYang/AutoTorch/workflows/Upload%20Python%20Package/badge.svg)](https://github.com/StacyYang/AutoTorch/actions)
[![Build Docs](https://github.com/StacyYang/AutoTorch/workflows/Build%20Docs/badge.svg)](https://github.com/StacyYang/AutoTorch/actions)
[![Unit Test](https://github.com/StacyYang/AutoTorch/workflows/Python%20application/badge.svg)](https://github.com/StacyYang/AutoTorch/actions)

<div align="left">
  <a href="https://autotorch.org"><img src="https://raw.githubusercontent.com/StacyYang/AutoTorch/master/docs/source/_static/logo.jpg" width="350"></a>
</div>

created by [Stacy Yang](http://stacyyang.org/)

## [Documentation](https://autotorch.org/)
